#!/usr/bin/tclsh

set infile [lindex $::argv 0]
if {"$infile" == ""} {
  puts stderr "ERROR: $::argv0 missing infile"
  exit 1
}
set fdin [open $infile r]
set fdout stdout

set extension [file extension $infile]
set extension [string toupper $extension]
set replicate_axes {}

foreach letter {U V W} {
  if {[string first "$letter" $extension] >= 0} {
    lappend replicate_axes $letter
  }
}
set unsupported_chars {"[" "<"}

while 1 {
  if [eof $fdin] break
  incr lno
  set theline [gets $fdin]
  set line [string trim $theline]
  if {"$line" == ""} continue
  set line [string map {"\t" "" " " ""} $line]
  set line [string toupper $line]
  # remove ";" style comment:
  set idx [string first ";" $line]
  if {$idx >= 0} { set line [string range $line 0 [incr idx -1]] }
  # remove "(" style comment:
  set idx [string first "(" $line]
  if {$idx >= 0} { set line [string range $line 0 [incr idx -1]] }
  if {"$line" == ""} continue
  foreach c $unsupported_chars {
    if {[string first "$c" $line] >=0} {
      set err "Unsupported char <\[> "
      break
    }
    if [info exists err] break
  }
  set saveline $line
  set idx [string first "Z" $line]
  if {$idx >= 0} {
    set zval [string range $line [incr idx] end]
    set idx 0
    for {set idx 0} {$idx < [string len $zval]} {incr idx}  {
      set c [string range $zval $idx $idx]
      switch -exact $c {
         0 - 1 - 2 - 3 - 4 - 5 - 6 - 7 - 8 - 9 {}
         "-" - "+" - "." {}
         default {break}
      }
    } ;# for
    set zval [string range $zval 0 [incr idx -1]]
    set addon ""
    foreach letter $replicate_axes {
      set addon "$addon $letter$zval"
    }
    set line    "       $saveline $addon"
    puts $fdout ";orig: $saveline"
  } else {
    set line    "       $saveline"
  }
  puts $fdout "$line"
} ;# while

if [info exists err] {
  puts stderr "ERROR: $::argv0 $err in file $infile"
  exit 1
}
